pygeodesy.named._NamedBase

Package pygeodesy :: Module named :: Class _NamedBase |
[frames] | no frames]

# Class _NamedBase

    object --+
             |
        _Named --+
                 |
                _NamedBase

Known Subclasses:
  - ltpTuples._AbcBase
  - , albers._AlbersBase
  - , ltp.Attitude
  - , css.CassiniSoldner
  - , ltp.LocalCartesian
  - , ecef._EcefBase
  - , _NamedEnumItem
  - , css.Css
  - , vector3dBase.Vector3dBase
  - , azimuthal._AzimuthalBase
  - , utmupsBase.UtmUpsBase
  - , etm.ExactTransverseMercator
  - , ltp.Frustum
  - , karney._CapsBase
  - , geodesicx.gxarea.GeodesicAreaExact
  - , latlonBase.LatLonBase
  - , geodesici._IntersectBase
  - , ktm.KTransverseMercator
  - , lcc.Lcc
  - , mgrs.Mgrs
  - , osgr.Osgr
  - , webmercator.Wm
  - , geodesicx.gxarea._Accumulator

(INTERNAL) Base class with name.

Instance Methods
__repr__(self) Default `repr(self)`. |
__str__(self) Default `str(self)`. |
others(self, *other, **name_other_up) Refined class comparison, invoked as `.others(other)`, `.others(name=other)` or `.others(other, name='other')`. |
toRepr(self, **kwds) (INTERNAL) Could be overloaded. |
toStr(self, **kwds) Must be overloaded. |
Inherited from `_Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
Inherited from `_Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __repr__ (self) (Representation operator) |
Default `repr(self)`. Overrides: object.__repr__

### __str__ (self) (Informal representation operator) |
Default `str(self)`. Overrides: object.__str__

### others (self, *other, **name_other_up) |
Refined class comparison, invoked as `.others(other)`, `.others(name=other)` or `.others(other, name='other')`. Arguments: `other` - The other instance (any `type`). `name_other_up` - Overriding `name=other` and `up=1` keyword arguments. Returns: The `other` iff compatible with this instance's `class` or `type`. Raises: `TypeError` - Mismatch of the `other` and this instance's `class` or `type`.

### toRepr (self, **kwds) |
(INTERNAL) Could be overloaded. Arguments: `kwds` - Optional, `toStr` keyword arguments. Returns: `toStr`() with keyword arguments (as `str`). Overrides: _Named.toRepr

### toStr (self, **kwds) |
Must be overloaded. Overrides: _Named.toStr